/*****************************************************************************
 * TinyLily Harry Potter Luna Lovegood Spectrespecs
 * Light up your world with Spectrespecs to see all the wrackspurts out there
 * making minds fuzzy! Using a TinyLily processor with 2 TinyLily RGB LEDs 
 * attached to pins 0 and A0, this program will alternate blue (pin A0) and 
 * red (pin 0) to create a disorienting effect for viewers.
 * 
 * Hardware by: TinyCircuits
 * Written by: Laveréna Wienclaw for TinyCircuits
 * Initiated: 10-09-19
 * Updated:
 * 
 *****************************************************************************/

#include <FastLED.h>

#define RED_PIN     A0
#define BLUE_PIN    0
#define NUM_LEDS    1
#define BRIGHTNESS  64
#define LED_TYPE    WS2812B
#define COLOR_ORDER GRB
CRGB red_leds[NUM_LEDS];
CRGB blue_leds[NUM_LEDS];

#define UPDATES_PER_SECOND 100

TBlendType    currentBlending;
extern const TProgmemPalette16 myPalette_red PROGMEM;
extern const TProgmemPalette16 myPalette_blue PROGMEM;

void setup() {
  delay( 3000 ); // power-up safety delay
  FastLED.addLeds<LED_TYPE, RED_PIN, COLOR_ORDER>(red_leds, NUM_LEDS).setCorrection( TypicalLEDStrip );
  FastLED.addLeds<LED_TYPE, BLUE_PIN, COLOR_ORDER>(blue_leds, NUM_LEDS).setCorrection( TypicalLEDStrip );
  FastLED.setBrightness(  BRIGHTNESS );
  currentBlending = LINEARBLEND;
}

void loop() {
  static uint8_t startIndex = 0;
  startIndex = startIndex + 1; /* motion speed */
    
  FillLEDsFromPaletteColors( startIndex);
    
  FastLED.show();
  FastLED.delay(1000 / UPDATES_PER_SECOND);
}

void FillLEDsFromPaletteColors( uint8_t colorIndex)
{
    uint8_t brightness = 255;
    
    for( int i = 0; i < NUM_LEDS; i++) {
        red_leds[0] = ColorFromPalette( myPalette_red, colorIndex, brightness, currentBlending);
        blue_leds[0] = ColorFromPalette( myPalette_blue, colorIndex, brightness, currentBlending);
        colorIndex += 1; // Toggle this to speed up, or slow down rate of color
    }
    delay(5); // Toggle this to speed up, or slow down overall effect
}

const TProgmemPalette16 myPalette_red PROGMEM =
{
    CRGB::Red,
    CRGB::Red,
    CRGB::Red,
    CRGB::Red,
    
    CRGB::Black,
    CRGB::Black, 
    CRGB::Black,
    CRGB::Black,
    
    CRGB::Red,
    CRGB::Red,
    CRGB::Red,
    CRGB::Red,
    
    CRGB::Black,
    CRGB::Black, 
    CRGB::Black,
    CRGB::Black,
};

const TProgmemPalette16 myPalette_blue PROGMEM =
{
    CRGB::Black,
    CRGB::Black, 
    CRGB::Black,
    CRGB::Black,
    
    CRGB::Blue,
    CRGB::Blue,    
    CRGB::Blue,
    CRGB::Blue,
    
    CRGB::Black,
    CRGB::Black, 
    CRGB::Black,
    CRGB::Black,
    
    CRGB::Blue,
    CRGB::Blue,    
    CRGB::Blue,
    CRGB::Blue,
};
